@@ -14,6 +14,7 @@ from prettytable import PrettyTable, ALL
 from texttable import Texttable
 from twisted.internet import reactor, defer, stdio
 from twisted.internet.defer import inlineCallbacks
+from twisted.internet.error import TimeoutError
 from twisted.internet.error import ConnectionRefusedError
 from twisted.python import log
 from mfcloud import metadata
@@ -201,22 +202,6 @@ class ApiRpcClient(object):
 
         yield storage_sync(src, dst, confirm=True, verbose=True)
 
-        yield sleep(0.01)
-
-
-        # source = yield self.resolve_volume_port(source)
-        # destination = yield self.resolve_volume_port(destination)
-        #
-        # command = "rsync -v -r --exclude '.git' %(local_path)s %(remote_path)s" % {
-        #     'local_path': source,
-        #     'remote_path': destination,
-        # }
-        #
-        # print command
-        #
-        # os.system(command)
-
-
     @cli('List running tasks')
     @inlineCallbacks
     def ps(self, **kwargs):
@@ -232,12 +217,9 @@ class ApiRpcClient(object):
         except ConnectionRefusedError:
             print 'Can\'t connect to mfcloud server'
 
-        client.shutdown()
+        yield client.shutdown()
         yield sleep(0.01)
 
-        if self.stop_reactor:
-            reactor.stop()
-
     @cli('Kills task', arguments=(
         arg('task_id', help='Id of the task'),
     ))
@@ -392,33 +374,6 @@ class ApiRpcClient(object):
 
         return '\n' + str(x) + '\n'
 
-
-    @cli('List running processes')
-    @inlineCallbacks
-    def ps(self, follow=False, **kwargs):
-        self.last_lines = 0
-
-        def _print(data):
-            ret = self.on_print_list_result(data, as_string=True)
-
-            if self.last_lines > 0:
-                print '\033[1A' * self.last_lines
-
-            print ret
-
-            self.last_lines = ret.count('\n') + 2
-
-        if follow:
-            self.stop_reactor = False
-            while follow:
-                ret = yield self._remote_exec('list')
-                _print(ret)
-                yield sleep(1)
-        else:
-            ret = yield self._remote_exec('list')
-            _print(ret)
-
-
     @cli('List registered applications', arguments=(
         arg('name', default=None, help='Application name', nargs='?'),
         arg('-f', '--follow', default=False, action='store_true', help='Continuously run list command'),
@@ -687,13 +642,16 @@ def main(argv):
     if isinstance(args.func, str):
         log.msg('Starting task: %s' % args.func)
 
-        @inlineCallbacks
-        def do_call():
-            yield getattr(client, args.func)(**vars(args))
-            sleep(0.01)
+        def ok(result):
             reactor.stop()
 
-        do_call()
+        def err(failure):
+            print 'Unhandled failure: %s' % failure
+            reactor.stop()
+
+        d = getattr(client, args.func)(**vars(args))
+        d.addCallback(ok)
+        d.addErrback(err)
 
         reactor.run()
     else:
