@@ -60,6 +60,7 @@ from mfcloud.util import query_yes_no
 import re
 import os, json, pprint, datetime
 import inject
+from twisted.internet.base import BlockingResolver
 from twisted.python import log
 from mfcloud.events import EventBus
 from mfcloud.application import ApplicationController, Application
@@ -474,7 +475,16 @@ class FileIOCommandClient(basic.LineReceiver):
 
         if self.data.endswith('\r\n'):
             self.data = self.data[0:-2]
-        self.factory.controller.completed.callback(json.loads(self.data))
+
+        try:
+            data_decoded = json.loads(self.data)
+
+            self.factory.controller.completed.callback(data_decoded)
+        except ValueError as e:
+            print ('Incorrect data received: %s of len %d' % (self.data, len(self.data)))
+            self.factory.controller.completed.errback(e)
+
+
         """
             NOTE: reason is a twisted.python.failure.Failure instance
         """
@@ -528,8 +538,8 @@ class FileClient(object):
 
     def __init__(self, host='0.0.0.0', port=7081):
         super(FileClient, self).__init__()
-        self.host = host
         self.port = port
+        self.host = host
 
     def upload(self, path, source_path, **kwargs):
 
@@ -537,7 +547,7 @@ class FileClient(object):
 
         protocol = FileIOUploaderClientProtocol(path, source_path, kwargs)
         f = FileIOClientFactory(protocol, controller)
-        reactor.connectTCP(self.host, self.port, f)
+        reactor.connectTCP(self.host, self.port, f, timeout=2)
 
         return controller.completed
 
@@ -546,7 +556,7 @@ class FileClient(object):
 
         protocol = FileIODownloaderClient(path, target_path, kwargs)
         f = FileIOClientFactory(protocol, controller)
-        reactor.connectTCP(self.host, self.port, f)
+        reactor.connectTCP(self.host, self.port, f, timeout=2)
 
         return controller.completed
 
@@ -555,7 +565,7 @@ class FileClient(object):
 
         protocol = FileIOCommandClient(command, args)
         f = FileIOClientFactory(protocol, controller)
-        reactor.connectTCP(self.host, self.port, f)
+        reactor.connectTCP(self.host, self.port, f, timeout=4)
 
         return controller.completed
 
@@ -640,22 +650,6 @@ class VolumeStorageLocal(object):
     def get_snapshot(self):
         return directory_snapshot(self.path)
 
-    @inlineCallbacks
-    def sync_to(self, storage):
-        """
-        Syncronize files with another storage
-
-        :param storage: VolumeStorageLocal|VolumeStorageRemote
-        :return:
-        """
-
-        snapshot_src = yield self.get_snapshot()
-        snapshot_dst = yield storage.get_snapshot()
-
-        diff = compare(snapshot_src, snapshot_dst)
-
-        storage.sync(diff, self)
-
     def sync(self, volume_diff, source):
 
         for path in volume_diff['new']:
@@ -713,6 +707,9 @@ def get_storage(ref):
         port = int(port)
         volume = match.group(8)
 
+        # if not re.match('^[0-9\.]+$', host):
+        #     host = BlockingResolver().getHostByName(host)
+
         return VolumeStorageRemote(host, port, app_name=app, service=service, volume=volume)
     else:
         return VolumeStorageLocal(ref)
@@ -747,10 +744,14 @@ def storage_sync(src, dst, confirm=False, verbose=False):
         print('Calculating volume differences')
 
     snapshot_src = yield src.get_snapshot()
-    if verbose: print('.')
+    if verbose:
+        print('.')
 
     snapshot_dst = yield dst.get_snapshot()
-    if verbose: print('.')
+
+
+    if verbose:
+        print('.')
 
     volume_diff = compare(snapshot_src, snapshot_dst, drift=(time() - start))
 
@@ -780,7 +781,6 @@ def storage_sync(src, dst, confirm=False, verbose=False):
 
         for path in volume_diff['del']:
             yield dst.remove(path)
-
     finally:
         if len(paths_to_upload):
             rmtree(tmp_path)
\ No newline at end of file
